Retrieves the name of the attribute specified by an HDF5 attribute object.
Arguments
- h5attribute
An object of class H5IdComponent representing an attribute. Normally created by
H5Aopen()or similar.
Retrieves the name of the attribute specified by an HDF5 attribute object.
An object of class H5IdComponent representing an
attribute. Normally created by H5Aopen() or similar.