Return a copy of the dataset creation property list for a dataset
Source:R/H5D.R
H5Dget_create_plist.RdReturn a copy of the dataset creation property list for a dataset
Arguments
- h5dataset
Object of class H5IdComponent representing an open HDF5 dataset