Write data to dataset
Arguments
- h5dataset
Object of class H5IdComponent representing an open HDF5 dataset.
- buf
The R object containing the data to be written to the dataset.
- h5type
Datatype of the HDF5 dataset to be written. If left as
NULLit will use the dataype of the R object supplied tobuf.- h5spaceMem, h5spaceFile
H5IdComponent objects representing the memory and file dataspaces respectively. If these are left
NULLdataspaces that match the size and shape ofh5datasetwill be used.