Flush all buffers associated with a file to disk
Usage
H5Fflush(h5file, scope = h5default("H5F_SCOPE"))Arguments
- h5file
H5IdComponent representing any object associated with the file to be flushed.
- scope
Specifies whether the scope of the flushing action is global (flushes the entire virtual file) or local (flushes only the specified file). Valid values are
H5F_SCOPE_GLOBALandH5F_SCOPE_LOCAL.