Retrieve the name of an object from a given identifier
Arguments
- h5obj
An object of class H5IdComponent. Can represent a file, group, dataset or attribute.
Retrieve the name of an object from a given identifier
An object of class H5IdComponent. Can represent a file, group, dataset or attribute.