An identifier is no longer valid after it has been closed.
Arguments
- h5identifier
Object of class H5IdComponent.
Examples
h5file <- system.file("testfiles", "h5ex_t_array.h5", package = "rhdf5")
fid <- H5Fopen(h5file)
## test whether the identifer to the opened file is valid
H5Iis_valid(fid)
#> [1] TRUE
## the file ID is no longer valid after it has been closed
H5Fclose(fid)
H5Iis_valid(fid)
#> [1] FALSE