H5Lget_info() identifies the type of link specified by the the h5loc
and name arguments. This is more limited than the equivalent function in
the standard HDF5 library.
Arguments
- h5loc
An object of class H5IdComponent representing a H5 location identifier (file or group).
- name
The name of the link to be queried.