Find the number of attributes associated with an HDF5 object
Source:R/H5O_extras.R
H5Oget_num_attrs.RdFind the number of attributes associated with an HDF5 object
Arguments
- h5obj
An object of class H5IdComponent representing a H5 object identifier (file, group, or dataset).
- h5loc
An object of class H5IdComponent representing a H5 location identifier (file or group).
- name
The name of the object to be checked.