Get and set whether to create missing intermediate groups
Source:R/H5P.R
H5P_create_intermediate_group.RdGet and set whether to create missing intermediate groups
Usage
H5Pset_create_intermediate_group(h5plist, create_groups = TRUE)
H5Pget_create_intermediate_group(h5plist)Arguments
- h5plist
An object of class H5IdComponent representing a link creation property list.
- create_groups
A logical of length 1 specifying whether missing groups should be created when a new object is created. Default is
TRUE.