Get and set the type of storage used to store the raw data for a dataset
Source:R/H5P.R
H5P_layout.RdPossible options for the layout argument are:
H5D_COMPACTH5D_CONTIGUOUSH5D_CHUNKEDH5D_VIRTUAL
Usage
H5Pset_layout(h5plist, layout = h5default("H5D"))
H5Pget_layout(h5plist)Arguments
- h5plist
An object of class H5IdComponent representing a dataset creation property list.
- layout
A character giving the name of a dataset layout type.