Control the range of HDF5 library versions that will be compatible with a file.
Source:R/H5P.R
H5P_libver_bounds.RdControl the range of HDF5 library versions that will be compatible with a file.
Usage
H5Pset_libver_bounds(
h5plist,
libver_low = "H5F_LIBVER_EARLIEST",
libver_high = "H5F_LIBVER_LATEST"
)
H5Pget_libver_bounds(h5plist)Arguments
- h5plist
H5IdComponent object representing a file access property list.
- libver_low, libver_high
Define the earliest and latest versions of the HDF5 library that will be used when writing object in the file.