Get and set the number of object header message indexes
Arguments
- h5plist
H5IdComponent object representing the file creation property list
- nindexes
Number of shared object header message indexes to be available in files
Get and set the number of object header message indexes
H5IdComponent object representing the file creation property list
Number of shared object header message indexes to be available in files