Get and set the sizes of offsets and lengths used in an HDF5 file
Arguments
- h5plist
H5IdComponent object representing the file creation property list
- sizeof_addr
Offset size in bytes
- sizeof_size
Length size in bytes
Get and set the sizes of offsets and lengths used in an HDF5 file
H5IdComponent object representing the file creation property list
Offset size in bytes
Length size in bytes