Get and set the size of the symbol table B-tree 1/2 rank and the leaf node 1/2 size
Source:R/H5P.R
H5P_sym_k.RdGet and set the size of the symbol table B-tree 1/2 rank and the leaf node 1/2 size
Arguments
- h5plist
H5IdComponent object representing the file creation property list
- ik
Symbol table B-tree 1/2 rank
- lk
Symbol table leaf node 1/2 size