Copy an existing property list to create a new property list
Arguments
- h5plist
H5IdComponent object representing the property list to be copied.
Copy an existing property list to create a new property list
H5IdComponent object representing the property list to be copied.