Return the property list class identifier for a property list
Arguments
- h5plist
H5IdComponent object representing any type of HDF5 property list.
Return the property list class identifier for a property list
H5IdComponent object representing any type of HDF5 property list.