Get version information for objects in a file creation property list
Source:R/H5P.R
H5Pget_version.RdGet version information for objects in a file creation property list
Arguments
- h5plist
H5IdComponent object representing the file creation property list