Set whether to record timestamps for operations performed on an HDF5 object.
Source:R/H5P.R
H5Pobject_track_times.RdSet whether to record timestamps for operations performed on an HDF5 object.
Arguments
- h5plist
An H5IdComponent object representing an object creation property list.
- track_times
logicalspecifying whether times associated with an object should recorded.
Details
Objects created using high-level rhdf5 functions like
h5createDataset() will have this setting turned off. This was done to
ensure otherwise identical files returned the same md5 hash. This differs
from the default setting in HDF5, which is for objects to record the times
operations were performed on them.