Add the BZIP2 filter to the chunk processing pipeline.
Arguments
- h5plist
Object of class H5IdComponent representing a dataset creation property list.
- level
Compression level to be used by the selected algorithm.
Add the BZIP2 filter to the chunk processing pipeline.
Object of class H5IdComponent representing a dataset creation property list.
Compression level to be used by the selected algorithm.