Add the LZF filter to the chunk processing pipeline.
Arguments
- h5plist
Object of class H5IdComponent representing a dataset creation property list.
- h5tid
Deprecated. This argument is not used and will be ignored.
Add the LZF filter to the chunk processing pipeline.
Object of class H5IdComponent representing a dataset creation property list.
Deprecated. This argument is not used and will be ignored.