Given a reference and the file to which that reference applies,
H5Rdeference() will open the reference object and return an identifier.
Value
An object of class H5IdComponent representing the opened object
referenced by ref. This should be closed with the appropriate function
e.g. H5Dclose(), H5Oclose(), etc. when no longer needed.