Create a simple dataspace
Arguments
- dims
A numeric vector defining the initial dimensions of the dataspace. The length of
dimsdetermines the rank of the dataspace.- maxdims
A numeric vector with the same length length as
dims. Specifies the upper limit on the size of the dataspace dimensions. Only needs to be specified if this is different from the values given todims.- native
An object of class
logical. IfTRUE, array-like objects are treated as stored in HDF5 row-major rather than R column-major orientation. Usingnative = TRUEincreases HDF5 file portability between programming languages. A file written withnative = TRUEshould also be read withnative = TRUE.
Value
Returns an object of class H5IdComponent representing a dataspace.