Retrieve or set the character set to be used in a string datatype.
Examples
tid <- H5Tcopy("H5T_C_S1")
H5Tget_cset(tid)
#> [1] 0
H5Tset_cset(tid, "UTF-8")
#> [1] 0
H5Tget_cset(tid)
#> [1] 1
Retrieve or set the character set to be used in a string datatype.
tid <- H5Tcopy("H5T_C_S1")
H5Tget_cset(tid)
#> [1] 0
H5Tset_cset(tid, "UTF-8")
#> [1] 0
H5Tget_cset(tid)
#> [1] 1