Retrieve or set the type of padding used by string datatype
Examples
tid <- H5Tcopy("H5T_C_S1")
H5Tget_strpad(tid)
#> [1] 0
H5Tset_strpad(tid, "NULLPAD")
#> [1] 0
H5Tget_strpad(tid)
#> [1] 1
Retrieve or set the type of padding used by string datatype
tid <- H5Tcopy("H5T_C_S1")
H5Tget_strpad(tid)
#> [1] 0
H5Tset_strpad(tid, "NULLPAD")
#> [1] 0
H5Tget_strpad(tid)
#> [1] 1