Determine whether a datatype is a variable length string
Examples
tid <- H5Tcopy("H5T_C_S1")
H5Tset_size(tid, 3)
H5Tis_variable_str(tid)
#> [1] FALSE
Determine whether a datatype is a variable length string
tid <- H5Tcopy("H5T_C_S1")
H5Tset_size(tid, 3)
H5Tis_variable_str(tid)
#> [1] FALSE