Creates a group within an HDF5 file.
Arguments
- file
The filename (character) of the file in which the dataset will be located. For advanced programmers it is possible to provide an object of class H5IdComponent representing a H5 location identifier (file or group). See
H5Fcreate(),H5Fopen(),H5Gcreate(),H5Gopen()to create an object of this kind.- group
The name of the new group. The name can contain a hierarchy of groupnames, e.g.
"/group1/group2/newgroup", but the function will fail if the top level groups do not exists.
Examples
h5File <- tempfile(pattern = "ex_createGroup.h5")
h5createFile(h5File)
# create groups
h5createGroup(h5File, "foo")
h5createGroup(h5File, "foo/foobaa")
h5ls(h5File)
#> group name otype dclass dim
#> 0 / foo H5I_GROUP
#> 1 /foo foobaa H5I_GROUP