Additional functions for finding details of dataset chunking.
Arguments
- h5dataset
Object of class H5IdComponent representing an open HDF5 dataset.
Value
H5Dchunk_dims: If the supplied dataset is chunked returns a vector, with length equal to the rank of the dataset, containing the size of the dataset dimensions. ReturnsNULLif the given dataset is not chunked.H5Dis_chunked: returnsTRUEif a dataset is chunked andFALSEotherwise.