H5Dget_storage_size returns the amount of storage, in bytes, allocated in
an HDF5 file to hold a given dataset. This is the amount of space required
on-disk, which not typically a good indicator of the amount of memory
that will be required to read the complete dataset.
Arguments
- h5dataset
Object of class H5IdComponent representing an open HDF5 dataset