Open an existing HDF5 file
Usage
H5Fopen(
name,
flags = h5default("H5F_ACC_RD"),
fapl = NULL,
native = FALSE,
s3 = FALSE,
s3credentials = NULL
)Arguments
- name
The name (or path) of the HDF5 file to be opened.
- flags
Character string defining the access mode for opening the file.
- fapl
H5IdComponent object representing a file access property list. Leaving this argument as
NULLwill use the default HDF5 properties.- native
An object of class
logical. IfTRUE, array-like objects are treated as stored in HDF5 row-major rather than R column-major orientation. Usingnative = TRUEincreases HDF5 file portability between programming languages. A file written withnative = TRUEshould also be opened for reading withnative = TRUE.- s3
Logical. If
TRUE, the file specified innameis read using the HDF5 Read-Only S3 virtual file driver. Requires that Rhdf5lib was compiled with S3 support, and thatnameis anhttp://orhttps://URL.- s3credentials
A list of length three containing the AWS region, access key ID, and secret access key for accessing files in a private S3 bucket. Leave as
NULLfor anonymous access to public data.