Creates a reference to an object or dataset selection inside an HDF5 file.
Arguments
- h5loc
An
H5IdComponentobject representing the location to be pointed to by the created reference.- name
Character string giving the name of the object to be referenced, relative to the location given by
h5loc.- ref_type
The type of reference to create. Accepts either
H5R_OBJECTorH5R_DATASET_REGION.- h5space
An object of class
H5IdComponentrepresenting a dataspace with a selection set. This argument is only used if creating a reference to a dataset region, and will be ignored otherwise.
Value
An H5Ref object storing the reference.