A class representing one or more HDF5 references.
Details
The length of the val slot is dependent on both the number and type of
references stored in the object. H5R_OBJECT references are stored in 8
bytes, while H5R_DATASET_REGION references require 12 bytes. The length
of val will then be a multiple of 8 or 12 respectively. This also means
that references of different types cannot be combined in a single object.
Methods (by generic)
show(H5Ref): Print details of the object to screen.length(H5Ref): Return the number of references stored in anH5Refobject.c(H5Ref): Combine two or moreH5Refobjects. Objects must all contain the same type of reference, eitherH5R_OBJECTorH5R_DATASET_REFERENCE.[: Subset anH5Refobject.