Create or modify an HDF5 enum datatype
Arguments
- dtype_id
ID of HDF5 datatype to work with. For
H5Tenum_create, this is the identifier of the base data type, and must be an integer e.g.H5T_NATIVE_INT. ForH5Tenum_insertthis will be a datatype identifier created byH5Tenum_create.- name
The name of a the new enum member. This is analogous to a "level" in an R factor.
- value
The value of the new member. Must be compatible with the base datatype defined by
dtype_id.
Value
H5Tinsert_enum()returns an character representing the H5 identifier of the new datatype.H5Tset_precision()is called for its side-effect of modifying the existing datatype. It will invisibly returnTRUEif this is successfulFALSEif not.