Retrieve or set the precision of an HDF5 datatype
Value
H5Tget_precision()returns an integer giving the number of significant bits used by the given datatype.H5Tset_precision()is call for its side-effect of modifying the precision of a datatype. It will invisibly returnTRUEif this is successful and will stop with an error if the operation fails.