Read all attributes from a given location in an HDF5 file
Source:R/h5readAttributes.R
h5_readAttributes.RdRead all attributes from a given location in an HDF5 file
Arguments
- file
Character vector of length 1, giving the path to the HDF5
- name
Path within the HDF5 file to the object whose attributes should be read. The datasets present in
filecan be listed with the functionh5ls().- native
An object of class
logical. If TRUE, array-like objects are treated as stored in HDF5 row-major rather than R column-major orientation.- ...
Further arguments passed to
H5Aread().