Saves a number of R objects to an HDF5 file.
Arguments
- ...
The objects to be saved.
- file
The filename (character) of the file in which the dataset will be located. It is also possible to provide an object of class H5IdComponent representing a H5 location identifier (file or group). See
H5Fcreate(),H5Fopen(),H5Gcreate(),H5Gopen()to create an object of this kind.- name
A character vector of names for the datasets. The length of the name vector should match the number of objects.
- createnewfile
If
TRUE, a new file will be created if necessary.- native
An object of class
logical. If TRUE, array-like objects are treated as stored in HDF5 row-major rather than R column-major orientation. Usingnative = TRUEincreases HDF5 file portability between programming languages. A file written withnative = TRUEshould also be read withnative = TRUE