The rhdf5 package provides two categories of functions:
h5functions are high-level R functions that provide a convenient way of accessing HDF5 filesH5functions mirror much of the the HDF5 C API
The rhdf5 package provides two categories of functions:
h5 functions are high-level R functions that provide a convenient way of
accessing HDF5 files
H5 functions mirror much of the the HDF5 C API